<a name="readme-top"></a>

<!-- TABLE OF CONTENTS -->
<details>
  <summary>Table of Contents</summary>
    <ol>
        <li>
        <a href="#about-the-project">About The Project</a>
        </li>
        <li>
        <a href="#installation">Getting Started</a>
        </li>
        <li><a href="#usage">Usage</a></li>
        <li><a href="#roadmap">Roadmap</a></li>
        <li><a href="#contact">Contact</a></li>
        <li><a href="#acknowledgments">Acknowledgments</a></li>
    </ol>
</details>



<!-- ABOUT THE PROJECT -->
## About The Project

The Sri Lankan Advance Personal Income Tax (APIT) Calculator is a Python package that helps you calculate the APIT based on specified income ranges and tax rates.

<p align="right">(<a href="#readme-top">back to top</a>)</p>




## Installation

Install via PIP
   ```sh
   pip install apit-lk==0.1.2
   ```


<p align="right">(<a href="#readme-top">back to top</a>)</p>



<!-- USAGE EXAMPLES -->
## Usage
   ```sh
    #import calculate_apit
    from apit.calc import calculate_apit

    # Example usage
    gross_income = 140000
    result = calculate_apit(gross_income)
    print(reult)
   ```


<p align="right">(<a href="#readme-top">back to top</a>)</p>



<!-- ROADMAP -->
## Roadmap

- [x] Add Monthly Tax Deductions from Regular Profits from Employment APIT calculation
- [ ] Add Tax breakdown
- [ ] Add other calculation methods with breakdown ( ex: Lump-Sum-Payments,Tax-on-Tax Rates,Bonus..etc)


<p align="right">(<a href="#readme-top">back to top</a>)</p>


<!-- CONTACT -->
## Contact

Dinuth Perera - +94776793824 - pm@dinuth.me


<p align="right">(<a href="#readme-top">back to top</a>)</p>



<!-- ACKNOWLEDGMENTS -->
## Acknowledgments

Find from below offical Advance Personal Income Tax Tables​​​ & Rules.


* [Sri Lanka IRD - Advance Personal Income Tax Tables​​​ ](http://www.ird.gov.lk/en/publications/sitepages/apit_tax_tables.aspx?menuid=1502)

<p align="right">(<a href="#readme-top">back to top</a>)</p>




